skhubness.neighbors.NearestNeighbors
====================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: NearestNeighbors

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NearestNeighbors.__init__
      ~NearestNeighbors.fit
      ~NearestNeighbors.get_params
      ~NearestNeighbors.kcandidates
      ~NearestNeighbors.kneighbors
      ~NearestNeighbors.kneighbors_graph
      ~NearestNeighbors.radius_neighbors
      ~NearestNeighbors.radius_neighbors_graph
      ~NearestNeighbors.set_params
   
   

   
   
   